#' This is a look up table data for internal use only.
#' @docType data
#' @keywords internal look up data
"datalms5_19"
